@@ -356,9 +356,8 @@ void build_widgets()
    ch * HDF_tip = "Combine near/far focus images for deeper focus";
    ch * stack_paint_tip = "Combine multiple photos to erase passing people, etc.";
    ch * stack_noise_tip = "Combine multiple noisy photos into a low-noise image";
-   ch * stack_layer_tip = "Combine image layers, mouse paint shown layers";
+   ch * stack_versions_tip = "Combine image versions, mouse paint areas/versions";
    ch * stack_split_tip = "Compare two images split by sliding boundary";
-   ch * image_diffs_tip = "Show differences between two images";
    ch * panorama_tip = "Combine images into a panorama";
    ch * show_cim_files_tip = "Show input files for above combine functions";
    ch * mashup_tip = "Arrange images and text in a layout (montage)";
@@ -610,9 +609,8 @@ void build_widgets()
    MENU(mComb,    "HDF", 0,                      HDF_tip,                   m_HDF, 0 );
    MENU(mComb,    "Stack/Paint", 0,              stack_paint_tip,           m_stack_paint, 0 );
    MENU(mComb,    "Stack/Noise", 0,              stack_noise_tip,           m_stack_noise, 0 );
-   MENU(mComb,    "Stack/Layer", 0,              stack_layer_tip,           m_stack_layer, 0 );
+   MENU(mComb,    "Stack/Versions", 0,           stack_versions_tip,        m_stack_versions, 0 );
    MENU(mComb,    "Stack/Split", 0,              stack_split_tip,           m_stack_split, 0 );
-   MENU(mComb,    "Image Diffs", 0,              image_diffs_tip,           m_image_diffs, 0);
    MENU(mComb,    "Panorama", 0,                 panorama_tip,              m_panorama, 0 );
    MENU(mComb,    "Show CIM Files", 0,           show_cim_files_tip,        m_cim_show_files, 0 );
    MENU(mComb,    "Mashup", 0,                   mashup_tip,                m_mashup, 0 );
@@ -838,7 +836,8 @@ void build_widgets()
    KBshort("Rotate",             m_rotate,                  0     );
    KBshort("Save",               m_file_save,               0     );
    KBshort("Search",             m_search_images,           0     );
-   KBshort("Select Files",       m_select_files,            0     );
+   KBshort("Select Area",        m_select_area,             0     );   
+   KBshort("Select Files",       m_select_files,            0     );   
    KBshort("Sharpen",            m_sharpen,                 0     );
    KBshort("Show Hidden",        m_show_hidden,             0     );
    KBshort("Show on Map",        m_netmap_zoomin,           0     ); 
